pub trait Key<K, V>: Copy {
    type Storage: Storage<K, V>;
}
The trait for a key that can be used to store values in the maps.

Required Associated Types

The Storage implementation to use for the key implementing this trait.

Implementations on Foreign Types

Implementors