Raw access to underlying storage.
This can be useful to implement more efficient serialization, since it might provide access to smaller primitive values.
Traits
- Trait implemented for storage which can be easily converted to and from a raw value.