Module for the trait to define Storage.
Structs
Storage for
bools.Storage for static types that must be stored in a map.
Storage for
Option<T>s.Storage types that can only inhabit a single value (like
()).Traits
The trait defining how storage works.