pub struct BooleanStorage<V> { /* fields omitted */ }type Iter = Iter<V>
Immutable iterator over storage. Uses raw pointers (unsafe) since we don't have GATs. Read more
type IterMut = IterMut<V>
Mutable iterator over storage. Uses raw pointers (unsafe) since we don't have GATs. Read more
This is the storage abstraction for Map::insert.
This is the storage abstraction for Map::get.
This is the storage abstraction for Map::get_mut.
This is the storage abstraction for Map::remove.
This is the storage abstraction for Map::clear.
This is the storage abstraction for Map::iter.
This is the storage abstraction for Map::iter_mut.
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Performs copy-assignment from source. Read more
Returns the "default value" for a type. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more