pub trait Key<K, V>: Copy { type Storage: Storage<K, V>; }
The trait for a key that can be used to store values in the maps.
The Storage implementation to use for the key implementing this trait.
Storage