Trait fixed_map::key::Key[][src]

pub trait Key<K, V>: Copy {
    type Storage: Storage<K, V>;
}
The trait for a key that can be used to store values in the maps.

Associated Types

type Storage: Storage<K, V>[src]

The Storage implementation to use for the key implementing this trait.

Implementations on Foreign Types

impl<V> Key<&'static str, V> for &'static str[src]

type Storage = MapStorage<Self, V>

impl<K, V> Key<Option<K>, V> for Option<K> where
    K: Key<K, V>, 
[src]

type Storage = OptionStorage<K, V>

impl<V> Key<char, V> for char[src]

impl<V> Key<u8, V> for u8[src]

type Storage = MapStorage<u8, V>

impl<V> Key<u32, V> for u32[src]

impl<V> Key<u64, V> for u64[src]

impl<V> Key<u128, V> for u128[src]

impl<V> Key<usize, V> for usize[src]

impl<V> Key<i8, V> for i8[src]

type Storage = MapStorage<i8, V>

impl<V> Key<i32, V> for i32[src]

impl<V> Key<i64, V> for i64[src]

impl<V> Key<i128, V> for i128[src]

impl<V> Key<isize, V> for isize[src]

impl<V> Key<(), V> for ()[src]

impl<V> Key<bool, V> for bool[src]

Implementors