Module fixed_map::map

source ·
Contains the fixed Map implementation.

Structs

  • A fixed map with storage specialized through the Key trait.

Enums

  • A view into a single entry in a map, which may either be vacant or occupied.

Traits

Type Aliases