Module fixed_map::storage

source ·
Module for the trait to define Storage.

Structs

Storage for static types that must be stored in a map.
Storage types that only has a single value (like ()).

Traits

The trait defining how storage works.