☰
Module storage
Structs
Traits
?
Module
fixed_map
::
storage
source
·
[
−
]
Module for the trait to define
Storage
.
Structs
MapStorage
Storage for static types that must be stored in a map.
SingletonStorage
Storage types that only has a single value (like
()
).
Traits
Storage
The trait defining how storage works.